watcher

package
v0.0.0-...-6f2359a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2019 License: Apache-2.0 Imports: 13 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Watcher

type Watcher struct {
	// contains filtered or unexported fields
}

Watcher watches the content of websites for changes and notifies people.

func New

func New(logger *logrus.Entry, storage storageClient, puppet puppetMasterClient, configFile string, config *api.Config) *Watcher

New returns a new watcher instance

func (*Watcher) AddNotifier

func (w *Watcher) AddNotifier(n notifier) error

AddNotifier adds a notifier to the list of known notifiers.

func (*Watcher) CheckConfig

func (w *Watcher) CheckConfig() error

CheckConfig checks the config for common and/or known mistakes

func (*Watcher) RegisterCronJobs

func (w *Watcher) RegisterCronJobs(cron *cron.Cron) error

RegisterCronJobs registers all jobs taken from config at the given cron instance

func (*Watcher) RunNow

func (w *Watcher) RunNow() error

RunNow executes all jobs instantly and in series

Jump to