Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Watcher ¶
type Watcher struct {
// contains filtered or unexported fields
}
Watcher watches the content of websites for changes and notifies people.
func New ¶
func New(logger *logrus.Entry, storage storageClient, puppet puppetMasterClient, configFile string, config *api.Config) *Watcher
New returns a new watcher instance
func (*Watcher) AddNotifier ¶
AddNotifier adds a notifier to the list of known notifiers.
func (*Watcher) CheckConfig ¶
CheckConfig checks the config for common and/or known mistakes
func (*Watcher) RegisterCronJobs ¶
RegisterCronJobs registers all jobs taken from config at the given cron instance
Click to show internal directories.
Click to hide internal directories.